pub trait FormatInfo {
// Required method
fn file_extension(&self) -> &str;
// Provided method
fn is_utf8(&self) -> bool { ... }
}Expand description
Information about a specific format, such as its file extension
Required Methods
Sourcefn file_extension(&self) -> &str
fn file_extension(&self) -> &str
Returns the file extension associated with this format (without the dot)